'use strict';

/**
 * Module dependencies
 */

// Public node modules.
const _ = require('lodash');
const path = require('path');

// Variables.
const initialRoutes = [];

module.exports = zenapi => {

  return {
    beforeInitialize: function() {
      zenapi.config.middleware.load.before.push('documentation');

      initialRoutes.push(..._.cloneDeep(zenapi.plugins.documentation.config.routes));
    },
    
    initialize: function(cb) {
      // Find the plugins routes.
      zenapi.plugins.documentation.config.routes = zenapi.plugins.documentation.config.routes
        .map((route, index) => {
          if (route.handler === 'Documentation.getInfos') {
            return route;
          }

          if (route.handler === 'Documentation.index' || route.path === '/login') {
            route.config.policies = initialRoutes[index].config.policies;
          }
          
          // Set prefix to empty to be able to customise it.
          if (_.get(zenapi.plugins, ['documentation', 'config', 'x-zenapi-config', 'path'])) {
            route.config.prefix = '';
            route.path = `/${zenapi.plugins.documentation.config['x-zenapi-config'].path}${route.path}`.replace('//', '/');
          }

          return route;
        });

      zenapi.router.route({
        method: 'GET',
        path: '/plugins/documentation/*.*',
        handler: [
          async (ctx, next) => {
            ctx.url = path.basename(ctx.url);

            return await zenapi.koaMiddlewares.static(`./plugins/documentation/node_modules/swagger-ui-dist`, {
              maxage: zenapi.config.middleware.settings.public.maxAge,
              defer: true
            })(ctx, next);
          }
        ]
      });

      cb();
    }
  };
};